# Windowsget: Python CLI

[![PyPI](https://img.shields.io/pypi/v/windowsget)](https://pypi.org/project/windowsget/)
[![Supported Python versions](https://img.shields.io/pypi/pyversions/windowsget.svg)](https://pypi.org/project/windowsget/)

Documentation: [https://c17hawke.github.io/windowsget/](https://c17hawke.github.io/windowsget/)

Basic usage -

1. Download file by passing your URL as argument after `windowsget`

    ```bash
    windowsget https://myexample.com/file.txt
    ```

2. Download file by passing your URL as argument after `windowsget` and specify output path with filename.

    ```bash
    windowsget https://myexample.com/file.txt -o mydir/myfile.txt
    ```
